==> ssh-3.1.2.tar.gz: ssh-3.1.2/lib/sshcrypto/sshcryptocore/genaux.c <==
/*

genaux.c

Author: Tatu Ylonen <ylo@ssh.fi>

Copyright (c) 1996-2000 SSH Communications Security, Finland
                   All rights reserved

*/

/*
 * $Id: genaux.c,v 1.1 2001/07/25 08:44:16 tmo Exp $
 * $Log: genaux.c,v $ * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * $EndLog$
 */

#include "sshincludes.h"
#include "sshcrypt.h"

/* Returns the string representation of the error returned (in English). */

const char *
ssh_crypto_status_message(SshCryptoStatus status)
{
  switch (status)
    {
    case SSH_CRYPTO_OK:
      return "Operation was successful";
    case SSH_CRYPTO_UNSUPPORTED:
      return "Algorithm or key not supported";
    case SSH_CRYPTO_DATA_TOO_LONG:
      return "Data is too long";
    case SSH_CRYPTO_INVALID_PASSPHRASE:
      return "Invalid passphrase";
    case SSH_CRYPTO_BLOCK_SIZE_ERROR:
      return "Block cipher block size constraint violation";
    case SSH_CRYPTO_KEY_TOO_SHORT:
      return "Key is too short for the algorithm";
    case SSH_CRYPTO_OPERATION_FAILED:
      return "Operation failed";
    case SSH_CRYPTO_UNSUPPORTED_IDENTIFIER:
      return "Identifier not supported";
    case SSH_CRYPTO_SCHEME_UNKNOWN:
      return "Scheme not supported";
    case SSH_CRYPTO_UNKNOWN_GROUP_TYPE:
      return "Group type given not recognized";
    case SSH_CRYPTO_UNKNOWN_KEY_TYPE:
      return "Key type given not recognized";
    case SSH_CRYPTO_KEY_UNINITIALIZED:
      return "Key should have been initialized";
    case SSH_CRYPTO_CORRUPTED_KEY_FORMAT:
      return "Key format was corrupted";
    case SSH_CRYPTO_LIBRARY_CORRUPTED:
      return "Internal error";
    default:
      return "Unknown error code";
    }
}

==> ssh-3.2.9.1.tar.gz: ssh-3.2.9.1/lib/sshcrypto/sshcryptocore/genaux.c <==
/*

genaux.c

Author: Tatu Ylonen <ylo@ssh.fi>

Copyright (c) 1996-2001 SSH Communications Security, Finland
                   All rights reserved

*/

/*
 * $Id: genaux.c,v 1.2 2001/12/12 13:25:06 mtr Exp $
 * $Log: genaux.c,v $ * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * 
 * $EndLog$
 */

#include "sshincludes.h"
#include "sshcrypt.h"

/* Returns the string representation of the error returned (in English). */

const char *
ssh_crypto_status_message(SshCryptoStatus status)
{
  switch (status)
    {
    case SSH_CRYPTO_OK:
      return "Operation was successful";
    case SSH_CRYPTO_UNSUPPORTED:
      return "Algorithm or key not supported";
    case SSH_CRYPTO_DATA_TOO_LONG:
      return "Data is too long";
    case SSH_CRYPTO_INVALID_PASSPHRASE:
      return "Invalid passphrase";
    case SSH_CRYPTO_BLOCK_SIZE_ERROR:
      return "Block cipher block size constraint violation";
    case SSH_CRYPTO_KEY_TOO_SHORT:
      return "Key is too short for the algorithm";
    case SSH_CRYPTO_OPERATION_FAILED:
      return "Operation failed";
    case SSH_CRYPTO_UNSUPPORTED_IDENTIFIER:
      return "Identifier not supported";
    case SSH_CRYPTO_SCHEME_UNKNOWN:
      return "Scheme not supported";
    case SSH_CRYPTO_UNKNOWN_GROUP_TYPE:
      return "Group type given not recognized";
    case SSH_CRYPTO_UNKNOWN_KEY_TYPE:
      return "Key type given not recognized";
    case SSH_CRYPTO_KEY_UNINITIALIZED:
      return "Key should have been initialized";
    case SSH_CRYPTO_CORRUPTED_KEY_FORMAT:
      return "Key format was corrupted";
    case SSH_CRYPTO_SIGNATURE_CHECK_FAILED:
      return "Signature check failed";
    case SSH_CRYPTO_PROVIDER_SLOTS_EXHAUSTED:
      return "Provider not registered because no slots were available";
    case SSH_CRYPTO_SMART_CARD_MISSING:
      return "Smart card missing";
    case SSH_CRYPTO_PROVIDER_ERROR:
      return "Externalkey provider error";
    case SSH_CRYPTO_OPERATION_CANCELLED:
      return "Operation cancelled";
    case SSH_CRYPTO_NO_MEMORY:
      return "Out of memory";
    case SSH_CRYPTO_LIBRARY_CORRUPTED:
      return "Internal error";
    default:
      return "Unknown error code";
    }
}
